==> kmymoney_5.1.1.orig.tar.xz: kmymoney-5.1.1/kmymoney/plugins/views/reports/reportsview.json.cmake <==
{
    "KPlugin": {
        "Authors": [
            {
                "Email": "asoliverez@gmail.com,lukasz.wojnilowicz@gmail.com",
                "Name": "Alvaro Soliverez,Łukasz Wojniłowicz",
                "Name[ca@valencia]": "Alvaro Soliverez,Łukasz Wojniłowicz",
                "Name[ca]": "Alvaro Soliverez,Łukasz Wojniłowicz",
                "Name[cs]": "Alvaro Soliverez,Łukasz Wojniłowicz",
                "Name[de]": "Alvaro Soliverez,Łukasz Wojniłowicz",
                "Name[en_GB]": "Alvaro Soliverez,Łukasz Wojniłowicz",
                "Name[es]": "Alvaro Soliverez,Łukasz Wojniłowicz",
                "Name[et]": "Alvaro Soliverez, Łukasz Wojniłowicz",
                "Name[eu]": "Alvaro Soliverez,Łukasz Wojniłowicz",
                "Name[fi]": "Alvaro Soliverez, Łukasz Wojniłowicz",
                "Name[fr]": "Alvaro Soliverez,Łukasz Wojniłowicz",
                "Name[gl]": "Alvaro Soliverez,Łukasz Wojniłowicz",
                "Name[ia]": "Alvaro Soliverez,Łukasz Wojniłowicz",
                "Name[it]": "Alvaro Soliverez,Łukasz Wojniłowicz",
                "Name[ko]": "Alvaro Soliverez,Łukasz Wojniłowicz",
                "Name[nl]": "Alvaro Soliverez,Łukasz Wojniłowicz",
                "Name[pl]": "Alvaro Soliverez,Łukasz Wojniłowicz",
                "Name[pt]": "Alvaro Soliverez,Łukasz Wojniłowicz",
                "Name[pt_BR]": "Alvaro Soliverez,Łukasz Wojniłowicz",
                "Name[ru]": "Alvaro Soliverez,Łukasz Wojniłowicz",
                "Name[sk]": "Alvaro Soliverez,Łukasz Wojniłowicz",
                "Name[sv]": "Alvaro Soliverez,Łukasz Wojniłowicz",
                "Name[uk]": "Alvaro Soliverez,Łukasz Wojniłowicz",
                "Name[x-test]": "xxAlvaro Soliverez,Łukasz Wojniłowiczxx"
            }
        ],
        "Description": "Adds reports view to KMyMoney",
        "Description[ca@valencia]": "Afig la vista dels informes al KMyMoney",
        "Description[ca]": "Afegeix la vista dels informes al KMyMoney",
        "Description[en_GB]": "Adds reports view to KMyMoney",
        "Description[es]": "Añade una vista de informes a KMyMoney",
        "Description[et]": "KMyMoney aruandevaade",
        "Description[eu]": "Txosten ikuspegia gehitzen dio KMyMoneyri",
        "Description[fi]": "Lisää KMyMoneyyn raporttinäkymän",
        "Description[fr]": "Ajoute la vue Rapports à KMyMoney",
        "Description[gl]": "Engade unha vista de informes a KMyMoney",
        "Description[it]": "Aggiunge la vista dei report a KMyMoney",
        "Description[ko]": "KMyMoney에 보고서 보기 추가",
        "Description[nl]": "Voegt weergave van rapporten toe aan KMyMoney",
        "Description[pl]": "Dodaje widok sprawozdań do KMyMoney",
        "Description[pt]": "Adiciona a área de relatórios ao KMyMoney",
        "Description[pt_BR]": "Adiciona área de relatórios no KMyMoney",
        "Description[sk]": "Pridá pohľad výpisov do KMyMoney",
        "Description[sv]": "Lägger till rapportvy i KMyMoney",
        "Description[uk]": "Панель звітів у KMyMoney",
        "Description[x-test]": "xxAdds reports view to KMyMoneyxx",
        "EnabledByDefault": true,
        "Icon": "report",
        "Id": "reportsview",
        "License": "GPL",
        "Name": "Reports view",
        "Name[ca@valencia]": "Vista dels informes",
        "Name[ca]": "Vista dels informes",
        "Name[de]": "Berichtsansicht",
        "Name[en_GB]": "Reports view",
        "Name[es]": "Vista de informes",
        "Name[et]": "Aruandevaade",
        "Name[eu]": "Txosten ikuspegia",
        "Name[fi]": "Raporttinäkymä",
        "Name[fr]": "Vue Rapports",
        "Name[gl]": "Vista de informes",
        "Name[ia]": "Vista de Reportos",
        "Name[it]": "Vista dei report",
        "Name[ko]": "보고서 보기",
        "Name[nl]": "Rapportenweergave",
        "Name[pl]": "Widok sprawozdań",
        "Name[pt]": "Área de relatórios",
        "Name[pt_BR]": "Área de relatórios",
        "Name[sk]": "Pohľad výpisov",
        "Name[sv]": "Rapportvy",
        "Name[uk]": "Перегляд звітів",
        "Name[x-test]": "xxReports viewxx",
        "ServiceTypes": [
            "KMyMoney/Plugin"
        ],
        "Version": "@PROJECT_VERSION@@PROJECT_VERSION_SUFFIX@",
        "Website": "https://kmymoney.org/plugins.html"
    }
}

==> kmymoney_5.1.2.orig.tar.xz: kmymoney-5.1.2/kmymoney/plugins/views/reports/reportsview.json.cmake <==
{
    "KPlugin": {
        "Authors": [
            {
                "Email": "asoliverez@gmail.com,lukasz.wojnilowicz@gmail.com",
                "Name": "Alvaro Soliverez,Łukasz Wojniłowicz",
                "Name[ca@valencia]": "Alvaro Soliverez,Łukasz Wojniłowicz",
                "Name[ca]": "Alvaro Soliverez,Łukasz Wojniłowicz",
                "Name[cs]": "Alvaro Soliverez,Łukasz Wojniłowicz",
                "Name[de]": "Alvaro Soliverez,Łukasz Wojniłowicz",
                "Name[en_GB]": "Alvaro Soliverez,Łukasz Wojniłowicz",
                "Name[es]": "Alvaro Soliverez,Łukasz Wojniłowicz",
                "Name[et]": "Alvaro Soliverez, Łukasz Wojniłowicz",
                "Name[eu]": "Alvaro Soliverez,Łukasz Wojniłowicz",
                "Name[fi]": "Alvaro Soliverez, Łukasz Wojniłowicz",
                "Name[fr]": "Alvaro Soliverez,Łukasz Wojniłowicz",
                "Name[gl]": "Alvaro Soliverez,Łukasz Wojniłowicz",
                "Name[ia]": "Alvaro Soliverez,Łukasz Wojniłowicz",
                "Name[it]": "Alvaro Soliverez,Łukasz Wojniłowicz",
                "Name[ko]": "Alvaro Soliverez,Łukasz Wojniłowicz",
                "Name[nl]": "Alvaro Soliverez,Łukasz Wojniłowicz",
                "Name[pl]": "Alvaro Soliverez,Łukasz Wojniłowicz",
                "Name[pt]": "Alvaro Soliverez,Łukasz Wojniłowicz",
                "Name[pt_BR]": "Alvaro Soliverez,Łukasz Wojniłowicz",
                "Name[ru]": "Alvaro Soliverez,Łukasz Wojniłowicz",
                "Name[sk]": "Alvaro Soliverez,Łukasz Wojniłowicz",
                "Name[sl]": "Alvaro Soliverez,Łukasz Wojniłowicz",
                "Name[sv]": "Alvaro Soliverez,Łukasz Wojniłowicz",
                "Name[uk]": "Alvaro Soliverez,Łukasz Wojniłowicz",
                "Name[x-test]": "xxAlvaro Soliverez,Łukasz Wojniłowiczxx",
                "Name[zh_CN]": "Alvaro Soliverez,Łukasz Wojniłowicz"
            }
        ],
        "Description": "Adds reports view to KMyMoney",
        "Description[ca@valencia]": "Afig la vista dels informes al KMyMoney",
        "Description[ca]": "Afegeix la vista dels informes al KMyMoney",
        "Description[en_GB]": "Adds reports view to KMyMoney",
        "Description[es]": "Añade una vista de informes a KMyMoney",
        "Description[et]": "KMyMoney aruandevaade",
        "Description[eu]": "Txosten ikuspegia gehitzen dio KMyMoneyri",
        "Description[fi]": "Lisää KMyMoneyyn raporttinäkymän",
        "Description[fr]": "Ajoute la vue Rapports à KMyMoney",
        "Description[gl]": "Engade unha vista de informes a KMyMoney",
        "Description[it]": "Aggiunge la vista dei report a KMyMoney",
        "Description[ko]": "KMyMoney에 보고서 보기 추가",
        "Description[nl]": "Voegt weergave van rapporten toe aan KMyMoney",
        "Description[pl]": "Dodaje widok sprawozdań do KMyMoney",
        "Description[pt]": "Adiciona a área de relatórios ao KMyMoney",
        "Description[pt_BR]": "Adiciona área de relatórios no KMyMoney",
        "Description[sk]": "Pridá pohľad výpisov do KMyMoney",
        "Description[sl]": "Doda pogled poročil v KMyMoney",
        "Description[sv]": "Lägger till rapportvy i KMyMoney",
        "Description[uk]": "Панель звітів у KMyMoney",
        "Description[x-test]": "xxAdds reports view to KMyMoneyxx",
        "Description[zh_CN]": "为 KMyMoney 添加报告视图",
        "EnabledByDefault": true,
        "Icon": "report",
        "Id": "reportsview",
        "License": "GPL",
        "Name": "Reports view",
        "Name[ca@valencia]": "Vista dels informes",
        "Name[ca]": "Vista dels informes",
        "Name[de]": "Berichtsansicht",
        "Name[en_GB]": "Reports view",
        "Name[es]": "Vista de informes",
        "Name[et]": "Aruandevaade",
        "Name[eu]": "Txosten ikuspegia",
        "Name[fi]": "Raporttinäkymä",
        "Name[fr]": "Vue Rapports",
        "Name[gl]": "Vista de informes",
        "Name[ia]": "Vista de Reportos",
        "Name[it]": "Vista dei report",
        "Name[ko]": "보고서 보기",
        "Name[nl]": "Rapportenweergave",
        "Name[pl]": "Widok sprawozdań",
        "Name[pt]": "Área de relatórios",
        "Name[pt_BR]": "Área de relatórios",
        "Name[sk]": "Pohľad výpisov",
        "Name[sl]": "Pogled poročil",
        "Name[sv]": "Rapportvy",
        "Name[uk]": "Перегляд звітів",
        "Name[x-test]": "xxReports viewxx",
        "Name[zh_CN]": "报表视图",
        "ServiceTypes": [
            "KMyMoney/Plugin"
        ],
        "Version": "@PROJECT_VERSION@@PROJECT_VERSION_SUFFIX@",
        "Website": "https://kmymoney.org/plugins.html"
    }
}
